==> kubernetes-model-apiextensions-5.9.0-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/JSONSchemaPropsOrBoolBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class JSONSchemaPropsOrBoolBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1.JSONSchemaPropsOrBoolFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1.JSONSchemaPropsOrBoolBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1.JSONSchemaPropsOrBool,io.fabric8.kubernetes.api.model.apiextensions.v1.JSONSchemaPropsOrBoolBuilder>{
  public JSONSchemaPropsOrBoolBuilder() {
    this(false);
  }
  public JSONSchemaPropsOrBoolBuilder(java.lang.Boolean validationEnabled) {
    this(new JSONSchemaPropsOrBool(), validationEnabled);
  }
  public JSONSchemaPropsOrBoolBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.JSONSchemaPropsOrBoolFluent<?> fluent) {
    this(fluent, false);
  }
  public JSONSchemaPropsOrBoolBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.JSONSchemaPropsOrBoolFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new JSONSchemaPropsOrBool(), validationEnabled);
  }
  public JSONSchemaPropsOrBoolBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.JSONSchemaPropsOrBoolFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1.JSONSchemaPropsOrBool instance) {
    this(fluent, instance, false);
  }
  public JSONSchemaPropsOrBoolBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.JSONSchemaPropsOrBoolFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1.JSONSchemaPropsOrBool instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAllows(instance.getAllows()); 
    fluent.withSchema(instance.getSchema()); 
    this.validationEnabled = validationEnabled; 
  }
  public JSONSchemaPropsOrBoolBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.JSONSchemaPropsOrBool instance) {
    this(instance,false);
  }
  public JSONSchemaPropsOrBoolBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.JSONSchemaPropsOrBool instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAllows(instance.getAllows()); 
    this.withSchema(instance.getSchema()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.apiextensions.v1.JSONSchemaPropsOrBoolFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.apiextensions.v1.JSONSchemaPropsOrBool build() {
    JSONSchemaPropsOrBool buildable = new JSONSchemaPropsOrBool(fluent.getAllows(),fluent.getSchema());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    JSONSchemaPropsOrBoolBuilder that = (JSONSchemaPropsOrBoolBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-apiextensions-5.11.2-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/JSONSchemaPropsOrBoolBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class JSONSchemaPropsOrBoolBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1.JSONSchemaPropsOrBoolFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1.JSONSchemaPropsOrBoolBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1.JSONSchemaPropsOrBool,io.fabric8.kubernetes.api.model.apiextensions.v1.JSONSchemaPropsOrBoolBuilder>{
  public JSONSchemaPropsOrBoolBuilder() {
    this(false);
  }
  public JSONSchemaPropsOrBoolBuilder(java.lang.Boolean validationEnabled) {
    this(new JSONSchemaPropsOrBool(), validationEnabled);
  }
  public JSONSchemaPropsOrBoolBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.JSONSchemaPropsOrBoolFluent<?> fluent) {
    this(fluent, false);
  }
  public JSONSchemaPropsOrBoolBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.JSONSchemaPropsOrBoolFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new JSONSchemaPropsOrBool(), validationEnabled);
  }
  public JSONSchemaPropsOrBoolBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.JSONSchemaPropsOrBoolFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1.JSONSchemaPropsOrBool instance) {
    this(fluent, instance, false);
  }
  public JSONSchemaPropsOrBoolBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.JSONSchemaPropsOrBoolFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1.JSONSchemaPropsOrBool instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAllows(instance.getAllows()); 
    fluent.withSchema(instance.getSchema()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public JSONSchemaPropsOrBoolBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.JSONSchemaPropsOrBool instance) {
    this(instance,false);
  }
  public JSONSchemaPropsOrBoolBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.JSONSchemaPropsOrBool instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAllows(instance.getAllows()); 
    this.withSchema(instance.getSchema()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.apiextensions.v1.JSONSchemaPropsOrBoolFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.apiextensions.v1.JSONSchemaPropsOrBool build() {
    JSONSchemaPropsOrBool buildable = new JSONSchemaPropsOrBool(fluent.getAllows(),fluent.getSchema());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    JSONSchemaPropsOrBoolBuilder that = (JSONSchemaPropsOrBoolBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
